Skip to contents

A 3x3 transition rate matrix used to simulate discrete states in the demonstration tree. This matrix defines the instantaneous rates of transition between states.

Usage

demo_Q

Format

A 3x3 numeric matrix

Examples

data(demo_Q)
demo_Q
#>      1    2    3
#> 1 -0.6  0.3  0.3
#> 2  0.3 -0.6  0.3
#> 3  0.3  0.3 -0.6
# Check that rows sum to 0
rowSums(demo_Q)
#> 1 2 3 
#> 0 0 0