A 3x3 transition rate matrix used to simulate discrete states in the demonstration tree. This matrix defines the instantaneous rates of transition between states.
A 3x3 transition rate matrix used to simulate discrete states in the demonstration tree. This matrix defines the instantaneous rates of transition between states.